import tables

# Note: 'expected_daily_rows' is an estimate, used to help PyTables
# choose a proper chunk size for the table.

layouts = {
    # Typical prep output
    "PrepData": {
        'expected_daily_rows': 120 * 86400,
        'description': {
            'timestamp': tables.Int64Col(pos=1),
            'p1': tables.Float32Col(pos=2),
            'q1': tables.Float32Col(pos=3),
            'p3': tables.Float32Col(pos=4),
            'q3': tables.Float32Col(pos=5),
            'p5': tables.Float32Col(pos=6),
            'q5': tables.Float32Col(pos=7),
            'p7': tables.Float32Col(pos=8),
            'q7': tables.Float32Col(pos=9),
        } },

    # Raw data
    "RawData": {
        'expected_daily_rows': 8000 * 86400,
        'description': {
            'timestamp': tables.Int64Col(pos=1),
            'va': tables.UInt16Col(pos=2),
            'vb': tables.UInt16Col(pos=3),
            'vc': tables.UInt16Col(pos=4),
            'ia': tables.UInt16Col(pos=5),
            'ib': tables.UInt16Col(pos=6),
            'ic': tables.UInt16Col(pos=7),
        } },

    # Raw data plus 60 Hz notched current
    "RawNotchedData": {
        'expected_daily_rows': 8000 * 86400,
        'description': {
            'timestamp': tables.Int64Col(pos=1),
            'va': tables.UInt16Col(pos=2),
            'vb': tables.UInt16Col(pos=3),
            'vc': tables.UInt16Col(pos=4),
            'ia': tables.UInt16Col(pos=5),
            'ib': tables.UInt16Col(pos=6),
            'ic': tables.UInt16Col(pos=7),
            'notch_ia': tables.UInt16Col(pos=8),
            'notch_ib': tables.UInt16Col(pos=9),
            'notch_ic': tables.UInt16Col(pos=10),
        } },
}

def description(layout):
    return tables.Description(layouts[layout]["description"])

def expected_daily_rows(layout):
    return layouts[layout]["expected_daily_rows"]
